@@ -190,6 +190,11 @@ static void vlc_event_callback(const libvlc_event_t *ev, void *data)
         (*env)->DeleteLocalRef(env, item_uri_value);
         (*env)->DeleteLocalRef(env, item_index);
         free(mrl);
+    } else if(ev->type == libvlc_MediaPlayerESAdded ||
+              ev->type == libvlc_MediaPlayerESDeleted ) {
+        jstring sData = (*env)->NewStringUTF(env, "data");
+        (*env)->CallVoidMethod(env, bundle, putInt, sData, ev->u.media_player_es_changed.i_type);
+        (*env)->DeleteLocalRef(env, sData);
     }
 
     /* Get the object class */
@@ -552,7 +557,9 @@ void Java_org_videolan_libvlc_LibVLC_playMRL(JNIEnv *env, jobject thiz,
         libvlc_MediaPlayerVout,
         libvlc_MediaPlayerPositionChanged,
         libvlc_MediaPlayerTimeChanged,
-        libvlc_MediaPlayerEncounteredError
+        libvlc_MediaPlayerEncounteredError,
+        libvlc_MediaPlayerESAdded,
+        libvlc_MediaPlayerESDeleted,
     };
     for(int i = 0; i < (sizeof(mp_events) / sizeof(*mp_events)); i++)
         libvlc_event_attach(ev, mp_events[i], vlc_event_callback, myVm);
