@@ -50,7 +50,7 @@ public class MediaDatabase {
 
     private SQLiteDatabase mDb;
     private static final String DB_NAME = "vlc_database";
-    private static final int DB_VERSION = 19;
+    private static final int DB_VERSION = 20;
     private static final int CHUNK_SIZE = 50;
 
     private static final String DIR_TABLE_NAME = "directories_table";
@@ -75,6 +75,7 @@ public class MediaDatabase {
     private static final String MEDIA_SPUTRACK = "spu_track";
     private static final String MEDIA_TRACKNUMBER = "track_number";
     private static final String MEDIA_DISCNUMBER = "disc_number";
+    private static final String MEDIA_LAST_MODIFIED = "last_modified";
 
     private static final String PLAYLIST_TABLE_NAME = "playlist_table";
     private static final String PLAYLIST_NAME = "name";
@@ -102,7 +103,7 @@ public class MediaDatabase {
         MEDIA_TABLE_NAME, MEDIA_PATH, MEDIA_TIME, MEDIA_LENGTH,
         MEDIA_TYPE, MEDIA_PICTURE, MEDIA_TITLE, MEDIA_ARTIST, MEDIA_GENRE, MEDIA_ALBUM,
         MEDIA_ALBUMARTIST, MEDIA_WIDTH, MEDIA_HEIGHT, MEDIA_ARTWORKURL, MEDIA_AUDIOTRACK,
-        MEDIA_SPUTRACK, MEDIA_TRACKNUMBER, MEDIA_DISCNUMBER
+        MEDIA_SPUTRACK, MEDIA_TRACKNUMBER, MEDIA_DISCNUMBER, MEDIA_LAST_MODIFIED
     }
 
     /**
@@ -191,7 +192,8 @@ public class MediaDatabase {
                     + MEDIA_AUDIOTRACK + " INTEGER, "
                     + MEDIA_SPUTRACK + " INTEGER, "
                     + MEDIA_TRACKNUMBER + " INTEGER, "
-                    + MEDIA_DISCNUMBER + " INTEGER"
+                    + MEDIA_DISCNUMBER + " INTEGER, "
+                    + MEDIA_LAST_MODIFIED + " INTEGER"
                     + ");";
             db.execSQL(query);
             db.execSQL("PRAGMA recursive_triggers='ON'"); //Needed for delete trigger
@@ -571,6 +573,7 @@ public class MediaDatabase {
         values.put(MEDIA_SPUTRACK, media.getSpuTrack());
         values.put(MEDIA_TRACKNUMBER, media.getTrackNumber());
         values.put(MEDIA_DISCNUMBER, media.getDiscNumber());
+        values.put(MEDIA_LAST_MODIFIED, media.getLastModified());
 
         mDb.replace(MEDIA_TABLE_NAME, "NULL", values);
 
@@ -652,7 +655,7 @@ public class MediaDatabase {
         do {
             count = 0;
             cursor = mDb.rawQuery(String.format(Locale.US,
-                    "SELECT %s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s FROM %s LIMIT %d OFFSET %d",
+                    "SELECT %s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s FROM %s LIMIT %d OFFSET %d",
                     MEDIA_LOCATION, //0 string
                     MEDIA_TIME, //1 long
                     MEDIA_LENGTH, //2 long
@@ -669,6 +672,7 @@ public class MediaDatabase {
                     MEDIA_SPUTRACK, //13 int
                     MEDIA_TRACKNUMBER, // 14 int
                     MEDIA_DISCNUMBER, //15 int
+                    MEDIA_LAST_MODIFIED, //16 long
                     MEDIA_TABLE_NAME,
                     CHUNK_SIZE,
                     chunk_count * CHUNK_SIZE), null);
@@ -692,7 +696,8 @@ public class MediaDatabase {
                             cursor.getInt(12),      // MEDIA_AUDIOTRACK
                             cursor.getInt(13),      // MEDIA_SPUTRACK
                             cursor.getInt(14),      // MEDIA_TRACKNUMBER
-                            cursor.getInt(15));     // MEDIA_DISCNUMBER
+                            cursor.getInt(15),     // MEDIA_DISCNUMBER
+                            cursor.getLong(16));     // MEDIA_LAST_MODIFIED
                     medias.put(media.getLocation(), media);
 
                     count++;
@@ -765,6 +770,7 @@ public class MediaDatabase {
                         MEDIA_SPUTRACK, //12 int
                         MEDIA_TRACKNUMBER, //13 int
                         MEDIA_DISCNUMBER, //14 int
+                        MEDIA_LAST_MODIFIED, //15 long
                 },
                 MEDIA_LOCATION + "=?",
                 new String[] { location },
@@ -790,7 +796,8 @@ public class MediaDatabase {
                     cursor.getInt(11),
                     cursor.getInt(12),
                     cursor.getInt(13),
-                    cursor.getInt(14));
+                    cursor.getInt(14),
+                    cursor.getLong(15));
         }
         cursor.close();
         return media;
