@@ -307,8 +307,7 @@ public class DirectoryAdapter extends BaseAdapter {
 
     @Override
     public Object getItem(int arg0) {
-        // TODO Auto-generated method stub
-        return null;
+        return mCurrentNode.children.get(arg0);
     }
 
     @Override
@@ -372,17 +371,15 @@ public class DirectoryAdapter extends BaseAdapter {
         else
             holder.icon.setImageResource(R.drawable.ic_menu_folder);
 
-        if (isChildFile(position)) {
-            holder.more.setVisibility(View.VISIBLE);
-            holder.more.setOnClickListener(new OnClickListener() {
-                @Override
-                public void onClick(View v) {
-                    if (mContextPopupMenuListener != null)
-                        mContextPopupMenuListener.onPopupMenu(v, position);
-                }
-            });
-        } else
-            holder.more.setVisibility(View.GONE);
+        holder.more.setVisibility(Util.canWrite(mCurrentDir+"/"+selectedNode.name) ? View.VISIBLE : View.INVISIBLE);
+        holder.more.setOnClickListener(new OnClickListener() {
+            @Override
+            public void onClick(View v) {
+                if (mContextPopupMenuListener != null)
+                    mContextPopupMenuListener.onPopupMenu(v, position);
+            }
+        });
+
         return v;
     }
 
