@@ -35,7 +35,6 @@ import android.os.Environment;
 import android.os.Handler;
 import android.preference.PreferenceManager;
 import android.support.v4.app.FragmentActivity;
-import android.support.v4.widget.SwipeRefreshLayout;
 import android.util.DisplayMetrics;
 import android.util.Log;
 import android.view.ContextMenu;
@@ -73,7 +72,9 @@ import org.videolan.vlc.gui.SecondaryActivity;
 import org.videolan.vlc.interfaces.ISortable;
 import org.videolan.vlc.interfaces.IVideoBrowser;
 import org.videolan.vlc.util.Util;
+import org.videolan.vlc.util.VLCInstance;
 import org.videolan.vlc.util.VLCRunnable;
+import org.videolan.vlc.widget.SwipeRefreshLayout;
 
 import java.util.HashMap;
 import java.util.List;
@@ -103,10 +104,10 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
 
     private VideoListAdapter mVideoAdapter;
     private MediaLibrary mMediaLibrary;
-    private LibVLC mLibVlc;
     private Thumbnailer mThumbnailer;
     private VideoGridAnimator mAnimator;
 
+    private MainActivity mMainActivity;
     private AudioServiceController mAudioController;
     private boolean mReady = true;
 
@@ -129,7 +130,6 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
         FragmentActivity activity = getActivity();
         if (activity != null)
             mThumbnailer = new Thumbnailer(activity, activity.getWindowManager().getDefaultDisplay());
-        mLibVlc = LibVLC.getInstance();
     }
     @Override
     public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState){
@@ -170,7 +170,6 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
         filter.addAction(Util.ACTION_SCAN_START);
         filter.addAction(Util.ACTION_SCAN_STOP);
         getActivity().registerReceiver(messageReceiverVideoListFragment, filter);
-        Log.i(TAG, "mMediaLibrary.isWorking() " + Boolean.toString(mMediaLibrary.isWorking()));
         if (mMediaLibrary.isWorking()) {
             Util.actionScanStart();
         }
@@ -181,7 +180,10 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
     @Override
     public void onPause() {
         super.onPause();
+        if (!(getActivity() instanceof MainActivity))
+            AudioServiceController.getInstance().unbindAudioService(getActivity());
         mGVFirstVisiblePos = mGridView.getFirstVisiblePosition();
+        mMediaLibrary.setBrowser(null);
         mMediaLibrary.removeUpdateHandler(mHandler);
 
         /* Stop the thumbnailer */
@@ -192,6 +194,11 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
     @Override
     public void onResume() {
         super.onResume();
+        if (!(getActivity() instanceof MainActivity))
+            AudioServiceController.getInstance().bindAudioService(getActivity());
+        else
+            mMainActivity = (MainActivity) getActivity();
+        mMediaLibrary.setBrowser(this);
         mMediaLibrary.addUpdateHandler(mHandler);
         final boolean refresh = mVideoAdapter.isEmpty();
         if (refresh)
@@ -324,7 +331,8 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
                             MediaWrapper media = (MediaWrapper) o;
                             mMediaLibrary.getMediaItems().remove(media);
                             mVideoAdapter.remove(media);
-                            mAudioController.removeLocation(media.getLocation());
+                            if (mAudioController.getMediaLocations().contains(media.getLocation()))
+                                mAudioController.removeLocation(media.getLocation());
                         }
                     });
             alertDialog.show();
@@ -351,7 +359,7 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
             menu.findItem(R.id.video_list_play_from_start).setVisible(true);
 
         boolean hasInfo = false;
-        final Media media = new Media(mLibVlc, mediaWrapper.getLocation());
+        final Media media = new Media(VLCInstance.get(), mediaWrapper.getLocation());
         media.parse();
         media.release();
         if (media.getMeta(Media.Meta.Title) != null)
@@ -462,26 +470,26 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
 
     @Override
     public void showProgressBar() {
-        if (getActivity() instanceof MainActivity)
-            MainActivity.showProgressBar();
+        if (mMainActivity != null)
+            mMainActivity.showProgressBar();
     }
 
     @Override
     public void hideProgressBar() {
-        if (getActivity() instanceof MainActivity)
-            MainActivity.hideProgressBar();
+        if (mMainActivity != null)
+            mMainActivity.hideProgressBar();
     }
 
     @Override
     public void clearTextInfo() {
-        if (getActivity() instanceof MainActivity)
-            MainActivity.clearTextInfo();
+        if (mMainActivity != null)
+            mMainActivity.clearTextInfo();
     }
 
     @Override
     public void sendTextInfo(String info, int progress, int max) {
-        if (getActivity() instanceof MainActivity)
-            MainActivity.sendTextInfo(info, progress, max);
+        if (mMainActivity != null)
+            mMainActivity.sendTextInfo(info, progress, max);
     }
 
     @Override
@@ -489,6 +497,11 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
         mVideoAdapter.sortBy(sortby);
     }
 
+    @Override
+    public int sortDirection(int sortby) {
+        return mVideoAdapter.sortDirection(sortby);
+    }
+
     public void setItemToUpdate(MediaWrapper item) {
         mItemToUpdate = item;
         mHandler.sendEmptyMessage(VideoListHandler.UPDATE_ITEM);
@@ -556,4 +569,8 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
                 }
             });
     }
+
+    public void clear(){
+        mVideoAdapter.clear();
+    }
 }
