@@ -24,14 +24,11 @@ import java.util.HashMap;
 import java.util.concurrent.BrokenBarrierException;
 import java.util.concurrent.CyclicBarrier;
 
-import org.videolan.libvlc.LibVLC;
-import org.videolan.libvlc.LibVlcException;
 import org.videolan.vlc.MediaDatabase;
 import org.videolan.vlc.MediaLibrary;
 import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.Thumbnailer;
-import org.videolan.vlc.gui.CompatErrorActivity;
 import org.videolan.vlc.gui.PreferencesActivity;
 import org.videolan.vlc.gui.tv.audioplayer.AudioPlayerActivity;
 import org.videolan.vlc.gui.tv.browser.MusicFragment;
@@ -80,6 +77,8 @@ public class MainTvActivity extends Activity implements IVideoBrowser, OnItemVie
     public static final long HEADER_NETWORK = 2;
     public static final long HEADER_MISC = 3;
 
+    private static final int ACTIVITY_RESULT_PREFERENCES = 1;
+
     public static final String BROWSER_TYPE = "browser_type";
 
     public static final String TAG = "VLC/MainTvActivity";
@@ -104,24 +103,21 @@ public class MainTvActivity extends Activity implements IVideoBrowser, OnItemVie
     @Override
     protected void onCreate(Bundle savedInstanceState) {
         super.onCreate(savedInstanceState);
+
+        if (!VLCInstance.testCompatibleCPU(this)) {
+            finish();
+            return;
+        }
+
         /*
          * skip browser and show directly Audio Player if a song is playing
          */
-        try {
-            if (VLCInstance.getLibVlcInstance() != null){
-                if (LibVLC.getExistingInstance().isPlaying()){
-                    startActivity(new Intent(this, AudioPlayerActivity.class));
-                    finish();
-                    return;
-                }
-            }
-        } catch (LibVlcException e) {
-            Intent i = new Intent(this, CompatErrorActivity.class);
-            startActivity(i);
+        if (VLCInstance.get().isPlaying()){
+            startActivity(new Intent(this, AudioPlayerActivity.class));
             finish();
-            super.onCreate(savedInstanceState);
             return;
         }
+
         mContext = this;
         setContentView(R.layout.tv_main_fragment);
 
@@ -188,6 +184,20 @@ public class MainTvActivity extends Activity implements IVideoBrowser, OnItemVie
             sThumbnailer.clearJobs();
     }
 
+    @Override
+    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
+        super.onActivityResult(requestCode, resultCode, data);
+        if (requestCode == ACTIVITY_RESULT_PREFERENCES) {
+            if (resultCode == PreferencesActivity.RESULT_RESCAN)
+                MediaLibrary.getInstance().loadMediaItems(this, true);
+            else if (resultCode == PreferencesActivity.RESULT_RESTART) {
+                Intent intent = getIntent();
+                finish();
+                startActivity(intent);
+            }
+        }
+    }
+
     @Override
     public boolean onKeyDown(int keyCode, KeyEvent event) {
         if ((keyCode == KeyEvent.KEYCODE_MEDIA_PLAY_PAUSE || keyCode == KeyEvent.KEYCODE_BUTTON_Y) && mSelectedItem instanceof MediaWrapper){
@@ -290,7 +300,7 @@ public class MainTvActivity extends Activity implements IVideoBrowser, OnItemVie
         } else if (row.getId() == HEADER_VIDEO)
             TvUtil.openMedia(mContext, item, row);
         else if (row.getId() == HEADER_MISC)
-            startActivity(new Intent(mContext, PreferencesActivity.class));
+            startActivityForResult(new Intent(this, PreferencesActivity.class), ACTIVITY_RESULT_PREFERENCES);
         else if (row.getId() == HEADER_NETWORK){
             TvUtil.openMedia(mContext, item, row);
         }
